Crate waterui_preview_protocol

Crate waterui_preview_protocol 

Shared TCP protocol between water CLI and the preview support app.

Modules

bench
Benchmark report wire format shared by waterui-testing and the water CLI.
hydrolysis
Offscreen Hydrolysis preview protocol.
registry
Preview support app instance registry shared between the CLI and local preview apps.
tcp
TCP configuration shared by the CLI and the preview support app.
transport
Framed binary transport helpers.

Structs

DylibId
Stable identifier for a preview dylib payload.
PreviewDylibLoadTimings
Timing breakdown for loading a preview dylib into the support app process.
PreviewOutput
Successful render output.
PreviewProtocolInfo
Protocol metadata exchanged during ping/pong handshake.
PreviewRenderTimings
Timing breakdown for a single preview render request inside the support app.
Size
Frame size for rendering.

Enums

DylibSource
How to provide the dylib used for rendering.
PreviewError
Errors that can occur during preview rendering.
PreviewRequest
Request from CLI to preview support app.
PreviewResponse
Response from preview support app.
PreviewRuntimePlatform
Runtime platform that owns the preview support app process.

Constants

PREVIEW_PROTOCOL_COMMIT
Build commit hash for protocol compatibility checks.

Functions

protocol_info
Return protocol metadata for handshake responses.