PreviewAppInstance

Struct PreviewAppInstance 

pub struct PreviewAppInstance {
    pub pid: u32,
    pub host: IpAddr,
    pub port: u16,
    pub waterui_core_fingerprint: String,
    pub registered_at_unix_ms: u64,
}
A registered local preview support app instance.

Fields

pid: u32

Operating-system process identifier of the support app.

host: IpAddr

Host address the support app listens on.

port: u16

TCP port the support app listens on.

waterui_core_fingerprint: String

Runtime fingerprint of the support app build.

registered_at_unix_ms: u64

Registration timestamp in milliseconds since the Unix epoch.

Implementations

Source

impl PreviewAppInstance

pub fn new( pid: u32, host: IpAddr, port: u16, waterui_core_fingerprint: impl Into<String>, ) -> Self

Create a registry entry for a support app instance.

Panics

Panics if the system clock predates the Unix epoch or its millisecond timestamp does not fit into u64.