pub struct PreviewDylibLoadTimings {
pub cache_file_ms: u64,
pub load_library_ms: u64,
pub initial_dlopen_ms: u64,
pub codesign_verify_ms: Option<u64>,
pub codesign_ms: Option<u64>,
pub reload_after_codesign_ms: Option<u64>,
}Expand description
Timing breakdown for loading a preview dylib into the support app process.
Fields
cache_file_ms: u64Time spent materializing the cached dylib file on disk.
load_library_ms: u64Total time spent loading the library from disk.
initial_dlopen_ms: u64Time spent in the initial dlopen.
codesign_verify_ms: Option<u64>Time spent verifying an existing code signature, if the initial dlopen failed.
codesign_ms: Option<u64>Time spent codesigning the dylib, if needed.
reload_after_codesign_ms: Option<u64>Time spent reloading the dylib after codesigning, if needed.