Shared TCP protocol between water CLI and the preview support app.
Modules
- bench
- Benchmark report wire format shared by
waterui-testingand thewaterCLI. - hydrolysis
- Offscreen Hydrolysis preview protocol.
- registry
- Preview support app instance registry shared between the CLI and local preview apps.
- tcp
- TCP configuration shared by the CLI and the preview support app.
- transport
- Framed binary transport helpers.
Structs
- DylibId
- Stable identifier for a preview dylib payload.
- Preview
Dylib Load Timings - Timing breakdown for loading a preview dylib into the support app process.
- Preview
Output - Successful render output.
- Preview
Protocol Info - Protocol metadata exchanged during ping/pong handshake.
- Preview
Render Timings - Timing breakdown for a single preview render request inside the support app.
- Size
- Frame size for rendering.
Enums
- Dylib
Source - How to provide the dylib used for rendering.
- Preview
Error - Errors that can occur during preview rendering.
- Preview
Request - Request from CLI to preview support app.
- Preview
Response - Response from preview support app.
- Preview
Runtime Platform - Runtime platform that owns the preview support app process.
Constants
- PREVIEW_
PROTOCOL_ COMMIT - Build commit hash for protocol compatibility checks.
Functions
- protocol_
info - Return protocol metadata for handshake responses.